==> eudplib-0.69.1.win-amd64.zip: P/Lib/site-packages/eudplib/ctrlstru/__init__.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014 trgk

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
"""

from .cshelper import CtrlStruOpener

from .basicstru import DoActions, EUDJump, EUDJumpIf, EUDJumpIfNot, EUDTernary

from .simpleblock import (
    EUDIf,
    EUDIfNot,
    EUDElseIf,
    EUDElseIfNot,
    EUDElse,
    EUDEndIf,
    EUDExecuteOnce,
    EUDEndExecuteOnce,
)

from .loopblock import (
    EUDInfLoop,
    EUDEndInfLoop,
    EUDLoopN,
    EUDEndLoopN,
    EUDLoopRange,
    EUDWhile,
    EUDWhileNot,
    EUDEndWhile,
)

from .swblock import EUDSwitch, EUDSwitchCase, EUDSwitchDefault, EUDEndSwitch

from .breakcont import (
    EUDContinue,
    EUDContinueIf,
    EUDContinueIfNot,
    EUDSetContinuePoint,
    EUDIsContinuePointSet,
    EUDBreak,
    EUDBreakIf,
    EUDBreakIfNot,
)

from .shortcircuit import EUDSCOr, EUDSCAnd

==> eudplib-0.70.9.win-amd64.zip: P/Lib/site-packages/eudplib/ctrlstru/__init__.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014 trgk

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
"""

from .cshelper import CtrlStruOpener

from .basicstru import DoActions, EUDJump, EUDJumpIf, EUDJumpIfNot, EUDTernary

from .simpleblock import (
    EUDIf,
    EUDIfNot,
    EUDElseIf,
    EUDElseIfNot,
    EUDElse,
    EUDEndIf,
    EUDExecuteOnce,
    EUDEndExecuteOnce,
)

from .loopblock import (
    EUDInfLoop,
    EUDEndInfLoop,
    EUDLoopN,
    EUDEndLoopN,
    EUDLoopRange,
    EUDWhile,
    EUDWhileNot,
    EUDEndWhile,
)

from .jumptable import GetCurrentJumpBuffer
from .swblock import EPDSwitch, EUDSwitch, EUDSwitchCase, EUDSwitchDefault, EUDEndSwitch

from .breakcont import (
    EUDContinue,
    EUDContinueIf,
    EUDContinueIfNot,
    EUDSetContinuePoint,
    EUDIsContinuePointSet,
    EUDBreak,
    EUDBreakIf,
    EUDBreakIfNot,
)

from .shortcircuit import EUDSCOr, EUDSCAnd
